@@ -278,6 +278,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_CERTIFY)
     }
 
+    /// Returns a KeyFlags where the certificate flag is set.
+    pub fn certification(self) -> Self {
+        KeyFlags::empty().set_certification()
+    }
+
     /// Declares that this key may be used to certify other keys.
     pub fn set_certification(self) -> Self {
         self.set(KEY_FLAG_CERTIFY)
@@ -302,6 +307,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_SIGN)
     }
 
+    /// Returns a KeyFlags where the signing flag is set.
+    pub fn signing(self) -> Self {
+        KeyFlags::empty().set_signing()
+    }
+
     /// Declares that this key may be used to sign data.
     pub fn set_signing(self) -> Self {
         self.set(KEY_FLAG_SIGN)
@@ -326,6 +336,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_ENCRYPT_FOR_TRANSPORT)
     }
 
+    /// Returns a KeyFlags where the transport encryption flag is set.
+    pub fn transport_encryption(self) -> Self {
+        KeyFlags::empty().set_transport_encryption()
+    }
+
     /// Declares that this key may be used to encrypt communications.
     pub fn set_transport_encryption(self) -> Self {
         self.set(KEY_FLAG_ENCRYPT_FOR_TRANSPORT)
@@ -350,6 +365,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_ENCRYPT_AT_REST)
     }
 
+    /// Returns a KeyFlags where the storage encryption flag is set.
+    pub fn storage_encryption(self) -> Self {
+        KeyFlags::empty().set_storage_encryption()
+    }
+
     /// Declares that this key may be used to encrypt storage.
     pub fn set_storage_encryption(self) -> Self {
         self.set(KEY_FLAG_ENCRYPT_AT_REST)
@@ -374,6 +394,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_AUTHENTICATE)
     }
 
+    /// Returns a KeyFlags where the authentication flag is set.
+    pub fn authentication(self) -> Self {
+        KeyFlags::empty().set_authentication()
+    }
+
     /// Declares that this key may be used for authentication.
     pub fn set_authentication(self) -> Self {
         self.set(KEY_FLAG_AUTHENTICATE)
@@ -399,6 +424,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_SPLIT_KEY)
     }
 
+    /// Returns a KeyFlags where the split key flag is set.
+    pub fn split_key(self) -> Self {
+        KeyFlags::empty().set_split_key()
+    }
+
     /// Declares that the private component of this key may have been
     /// split using a secret-sharing mechanism.
     pub fn set_split_key(self) -> Self {
@@ -427,6 +457,11 @@ impl KeyFlags {
         self.get(KEY_FLAG_GROUP_KEY)
     }
 
+    /// Returns a KeyFlags where the group flag is set.
+    pub fn group_key(self) -> Self {
+        KeyFlags::empty().set_group_key()
+    }
+
     /// Declares that the private component of this key is in
     /// possession of more than one person.
     pub fn set_group_key(self) -> Self {
